multiformats.varint
===================

.. automodule:: multiformats.varint

BytesLike
---------

.. autodata:: multiformats.varint.BytesLike

byteslike
---------

.. autodata:: multiformats.varint.byteslike

decode
------

.. autofunction:: multiformats.varint.decode

decode_raw
----------

.. autofunction:: multiformats.varint.decode_raw

encode
------

.. autofunction:: multiformats.varint.encode
